@@ -174,8 +174,11 @@ class Preprocessor(object):
             path = osp.basename(path)
         else:
             if not osp.isabs(path):
-                # Make sure path is relative to the file that is preprocessed
-                path = osp.abspath(osp.join(osp.dirname(self.filename), path))
+                if hasattr(self, 'filename'):
+                    # Make sure path is relative to the file that is preprocessed
+                    path = osp.abspath(osp.join(osp.dirname(self.filename), path))
+                else:
+                    path = osp.abspath(path)
         logger.debug('file[%s] = %s', key, path)
         self.files[key] = path
 
